@@ -1,5 +1,5 @@
 /* jpnevulator - serial reader/writer
- * Copyright (C) 2006-2009 Freddy Spierenburg
+ * Copyright (C) 2006-2012 Freddy Spierenburg
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,9 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#ifndef __USE_ISOC99
 #define __USE_ISOC99 /* for newly introduced isblank() */
+#endif
 #include <ctype.h>
 
 #include "byte.h"
